@@ -712,6 +712,8 @@ def build_book(book, publish_path, log_path):
     os.chdir(book)
     result = True
     returncode = 0
+    if cfg.CONF.debug:
+        print("Building in directory '%s'" % book)
     base_book = os.path.basename(book)
     base_book_orig = base_book
     comments = "-Dcomments.enabled=%s" % cfg.CONF.comments_enabled
@@ -771,7 +773,7 @@ def build_book(book, publish_path, log_path):
             base_book = "install-guide (for Debian, Fedora, openSUSE, Ubuntu)"
         elif base_book == "high-availability-guide":
             output = subprocess.check_output(
-                [os.path.join(SCRIPTS_DIR, 'build-ha-guide.sh'), ],
+                ["bash", os.path.join(SCRIPTS_DIR, 'build-ha-guide.sh'), ],
                 stderr=subprocess.STDOUT
             )
             output = subprocess.check_output(
@@ -782,13 +784,15 @@ def build_book(book, publish_path, log_path):
         # Let's not check for "v3" but for the full name instead
         elif book.endswith("openstack-identity-api/v3"):
             output = subprocess.check_output(
-                [os.path.join(SCRIPTS_DIR, "markdown-docbook.sh"),
+                ["bash", os.path.join(SCRIPTS_DIR, "markdown-docbook.sh"),
                  "identity-api-v3"],
                 stderr=subprocess.STDOUT
             )
             out_file.write(output)
             # File gets generated at wrong directory, we need to move it
             # around
+            if os.isfile('identity-api-v3.xml'):
+                os.remove('identity-api-v3.xml')
             shutil.move("src/markdown/identity-api-v3.xml", ".")
             output = subprocess.check_output(
                 ["mvn", "generate-sources", comments, release, "-B"],
@@ -797,7 +801,7 @@ def build_book(book, publish_path, log_path):
         # Repository: image-api
         elif base_book == 'image-api-v2':
             output = subprocess.check_output(
-                [os.path.join(SCRIPTS_DIR, "markdown-docbook.sh"),
+                ["bash", os.path.join(SCRIPTS_DIR, "markdown-docbook.sh"),
                  "image-api-v2.0"],
                 stderr=subprocess.STDOUT
             )
